﻿////////////////////////////////////////////////////////////////////////////////
//
//    Lock Monza R6 EPC Memory
//
////////////////////////////////////////////////////////////////////////////////

using System;
using Impinj.OctaneSdk;

namespace OctaneSdkExamples
{
    class Program
    {
        // Create an instance of the ImpinjReader class.
        static ImpinjReader reader = new ImpinjReader();

        static void Main(string[] args)
        {
            try
            {
                // Connect to the reader.
                // Change the ReaderHostname constant in SolutionConstants.cs 
                // to the IP address or hostname of your reader.
                reader.Connect(SolutionConstants.ReaderHostname);

                // Assign the TagOpComplete event handler.
                // This specifies which method to call
                // when tag operations are complete.
                reader.TagOpComplete += OnTagOpComplete;

                // Configure the reader with the default settings.
                reader.ApplyDefaultSettings();

                // Create a tag operation sequence.
                // You can add multiple read, write, lock, kill and QT
                // operations to this sequence.
                TagOpSequence seq = new TagOpSequence();

                // Create a tag lock operation to lock the EPC memory of Monza R6.
                // This is done by sending a Gen2 lock command with a payload of FFFFFh,
                // which is the equivalent of sending a command to lock permalock
                // every possible memory bank.
                TagLockOp lockOp = new TagLockOp();
                lockOp.KillPasswordLockType = TagLockState.Permalock;
                lockOp.AccessPasswordLockType = TagLockState.Permalock;
                lockOp.EpcLockType = TagLockState.Permalock;
                lockOp.TidLockType = TagLockState.Permalock;
                lockOp.UserLockType = TagLockState.Permalock;
                
                // Add this tag lock op to the tag operation sequence.
                seq.Ops.Add(lockOp);

                // Add the tag operation sequence to the reader.
                // The reader supports multiple sequences.
                reader.AddOpSequence(seq);

                // Start the reader
                reader.Start();
            }
            catch (OctaneSdkException e)
            {
                // Handle Octane SDK errors.
                Console.WriteLine("Octane SDK exception: {0}", e.Message);
            }
            catch (Exception e)
            {
                // Handle other .NET errors.
                Console.WriteLine("Exception : {0}", e.Message);
            }

            // Wait for the user to press enter.
            Console.WriteLine("Press enter to exit.");
            Console.ReadLine();

            // Stop reading.
            reader.Stop();

            // Disconnect from the reader.
            reader.Disconnect();
        }

        // This event handler will be called when tag 
        // operations have been executed by the reader.
        static void OnTagOpComplete(ImpinjReader reader, TagOpReport report)
        {
            // Loop through all the completed tag operations
            foreach (TagOpResult result in report)
            {
                if (result is TagLockOpResult)
                {
                    // Cast it to the correct type.
                    // These are the results of locking the access password or user memory.
                    TagLockOpResult lockResult = result as TagLockOpResult;
                    // Print out the results.
                    Console.WriteLine("Lock operation complete.");
                    Console.WriteLine("EPC : {0}", lockResult.Tag.Epc);
                    Console.WriteLine("Status : {0}", lockResult.Result);
                }
            }
        }
    }
}
